// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Custom QML component to change the color used to display spectra for different molecules
import QtQuick 2.0
import QtQuick.Controls 1.3
import QtQuick.Window 2.2
import QtQuick.Dialogs 1.2
import QtQuick.Layouts 1.1
import ColorPlot 1.0

Item {

    id: colorDialogItem
    anchors.fill: parent

    // Rectangle to draw the form border
    Rectangle {
        id: backRect
        anchors.fill: parent
        border.width: 1
        border.color: "black"
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        id: frameRect
        anchors.right: colorColumnLayout.right
        anchors.top: colorColumnLayout.top
        anchors.left: colorColumnLayout.left
        anchors.bottom: colorColumnLayout.bottom
        anchors.margins: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'android') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? titleLabel.height * (-0.85) : -20
        anchors.topMargin: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'android') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? titleLabel.height * (-0.7) : -20
        color: "white"
        border.width: 1
        border.color: "black"
        radius: height * 0.02
    }

    // Used to rotate the menu
    onHeightChanged:
    {
        if (Screen.primaryOrientation == Qt.PortraitOrientation)
        {
            colorColumnLayout.height = colorDialogItem.height - exitButton.height * 2.5
        }
        else
        {
            colorColumnLayout.height = colorDialogItem.height - exitButton.height * 0.7
        }
    }

    // Qml component is used in order to notify the user about the developer
    ColumnLayout {

        id: colorColumnLayout
        anchors.centerIn: parent

        // Label containing the title for the current window
        PlatformLabel {
            id: titleLabel
            anchors.top: colorColumnLayout.top
            text: " Select color to be used for ploting spectrum "
        }

        ColorPlot {
            id: colorPlot
            Layout.fillWidth: true
            anchors.top: titleLabel.bottom
            anchors.bottom: colorSlider.top
            color: MolListViewModel.selectedColor
            onColorChanged: MolListViewModel.selectedColor = colorPlot.color
            colorBarHeight: 40
            onHueValueChanged: colorSlider.value = hueValue
            hueValue: colorSlider.value

            MouseArea {
                id: plotMouseArea
                anchors.fill: parent
                onClicked: {
                    colorPlot.x = mouseX
                    colorPlot.y = mouseY
                }
                onPositionChanged: {
                    colorPlot.x = mouseX
                    colorPlot.y = mouseY
                }
            }
        }

        Slider {
            id: colorSlider
            Layout.fillWidth: true
            anchors.bottom: colorColumnLayout.bottom
            tickmarksEnabled: false
            updateValueWhileDragging: true
            stepSize: 0
            minimumValue: 0
            maximumValue: 359
            value: colorPlot.hueValue
            onValueChanged: colorPlot.hueValue = value
        }
    }

    // Button to close the form
    BackRectangle {
        anchors.fill: exitButton
        anchors.margins: 8
    }
    ControlButton {
        anchors.right: colorDialogItem.right
        anchors.top: colorDialogItem.top
        id: exitButton
        platformText: qsTr("X")
        opacity: 1.0

        // Enabling the closing of the form when the exit button is pressed
        MouseArea {
            anchors.fill: parent
            onClicked: {
                MolListViewModel.updateActiveColor();
                colorDialogItem.destroy();
            }
        }
    }
}

