// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object containing the main menu
import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Window 2.2
import QtQuick.Dialogs 1.2
import QtQuick.Layouts 1.1
import QtQuick.Controls.Styles 1.4

Item {

    // Need to prevent the possible repeat open of dialogs

    id: menuItem
    anchors.fill: parent
    opacity: 1.0

    // Making sure the menu is centered relative to the parent widget (QML window)
    anchors.horizontalCenter: parent.horizontalCenter;
    anchors.verticalCenter: parent.verticalCenter;

    // Used to rotate the menu and display show the button used to open the information about the program
    onHeightChanged:
    {        
        if (Screen.primaryOrientation == Qt.PortraitOrientation)
        {
            mainGridLayout.flow = GridLayout.TopToBottom
        }
        else
        {
            mainGridLayout.flow = GridLayout.LeftToRight
        }

        windowNumText.text = "menu page 1 of 2"

        wavelengthsButton.enabled = true
        pathlengthButton.enabled = true
        totalPressureButton.enabled = true
        temperatureButton.enabled = true
        yAxisButton.enabled = true
        atmModelButton.enabled = true
        lineOptionsButton.enabled = false
        instrFunctButton.enabled = false
        hitranDownloadOptionsButton.enabled = false
        shareResultsButton.enabled = false
        aboutButton.enabled = false

        wavelengthsButton.visible = true
        pathlengthButton.visible = true
        totalPressureButton.visible = true
        temperatureButton.visible = true
        yAxisButton.visible = true
        atmModelButton.visible = true
        lineOptionsButton.visible = false
        instrFunctButton.visible = false
        hitranDownloadOptionsButton.visible = false
        shareResultsButton.visible = false
        aboutButton.visible = false
    }

    // Rectangle to draw the form border
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: "black"
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the border around items
    Rectangle {
        id: menuRect
        anchors.right: mainGridLayout.right
        anchors.top: mainGridLayout.top
        anchors.left: mainGridLayout.left
        anchors.bottom: mainGridLayout.bottom
        anchors.margins: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'android') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? heightLabel.height * (-0.85) : -20
        color: "white"
        border.width: 1
        border.color: "black"
        radius: atmModelButton.width * 0.03
    }

    Label {
        id: heightLabel
        text: "label"
        visible: false
        enabled: false
    }

    // Had to implement it this way because Marshmellow resulted in semi-transparent buttons
    BackRectangle {
        anchors.fill: exitButton
        anchors.margins: 8
    }
    ControlButton {
        id: exitButton
        anchors.top: menuItem.top
        anchors.right: menuItem.right
        platformText: qsTr("X")
        anchors.margins: 0

        // Enabling the closing of the form when the exit button is pressed
        MouseArea {
            anchors.fill: parent
            onClicked: {
                menuItem.destroy();
            }
        }
    }

    RowLayout {
        id: bottomRowLayout
        Layout.fillWidth: true
        anchors.bottom: menuItem.bottom
        anchors.right: menuItem.right
        anchors.left: menuItem.left
        opacity: 1.0

        BackRectangle {
            anchors.fill: prevButton
            anchors.margins: 8
        }
        ControlButton {
            anchors.left: bottomRowLayout.left
            anchors.margins: 1
            id: prevButton
            platformText: qsTr("<<")            

            // Enabling the closing of the form when the exit button is pressed
            MouseArea {
                anchors.fill: parent
                onClicked: {

                    windowNumText.text = "menu page 1 of 2"

                    wavelengthsButton.enabled = true
                    pathlengthButton.enabled = true
                    totalPressureButton.enabled = true
                    temperatureButton.enabled = true
                    yAxisButton.enabled = true
                    atmModelButton.enabled = true
                    lineOptionsButton.enabled = false
                    instrFunctButton.enabled = false
                    hitranDownloadOptionsButton.enabled = false
                    shareResultsButton.enabled = false
                    aboutButton.enabled = false

                    wavelengthsButton.visible = true
                    pathlengthButton.visible = true
                    totalPressureButton.visible = true
                    temperatureButton.visible = true
                    yAxisButton.visible = true
                    atmModelButton.visible = true
                    lineOptionsButton.visible = false
                    instrFunctButton.visible = false
                    hitranDownloadOptionsButton.visible = false
                    shareResultsButton.visible = false
                    aboutButton.visible = false
                }
            }
        }

        Rectangle {
            id: windowNumRectangle
            anchors.left: prevButton.right
            anchors.right: nextButton.left
            Layout.fillHeight: true
            border.width: 0
            border.color: "white"
            color: 'transparent'

            Text {
                anchors.centerIn: parent
                id: windowNumText
                text: "menu page 1 of 2"
                font.bold: true
                horizontalAlignment: Text.AlignCenter
                color: 'white'
            }
        }

        BackRectangle {
            anchors.fill: nextButton
            anchors.margins: 8
        }
        ControlButton {
            anchors.right: bottomRowLayout.right
            implicitWidth: prevButton.width
            anchors.margins: 1
            id: nextButton
            platformText: qsTr(">>")            

            // Enabling the closing of the form when the exit button is pressed
            MouseArea {
                anchors.fill: parent
                onClicked: {

                    windowNumText.text = "menu page 2 of 2"

                    wavelengthsButton.enabled = false
                    pathlengthButton.enabled = false
                    totalPressureButton.enabled = false
                    temperatureButton.enabled = false
                    yAxisButton.enabled = false
                    atmModelButton.enabled = true
                    lineOptionsButton.enabled = true
                    instrFunctButton.enabled = true
                    hitranDownloadOptionsButton.enabled = true
                    shareResultsButton.enabled = true
                    aboutButton.enabled = true

                    wavelengthsButton.visible = false
                    pathlengthButton.visible = false
                    totalPressureButton.visible = false
                    temperatureButton.visible = false
                    yAxisButton.visible = false
                    atmModelButton.visible = true
                    lineOptionsButton.visible = true
                    instrFunctButton.visible = true
                    hitranDownloadOptionsButton.visible = true
                    shareResultsButton.visible = true
                    aboutButton.visible = true
                }
            }
        }
    }

    GridLayout {
        // At rotation the buttons are not positioned exactly the way they should be (fix this)
        id: mainGridLayout
        anchors.centerIn: parent
        rowSpacing: 5
        rows: 10
        columns: 2        

        // Changing the wavelength range
        MenuButton {
            Layout.fillWidth: true
            id: wavelengthsButton            
            implicitWidth: atmModelButton.width
            platformText: qsTr("  Wavelengths  ")
            setWidthFromText: false

            // Enabling opening of another window with the parameters of the wavelength range for the calculation
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("Wavelengths.qml")
                    if (component.status === Component.Ready)
                    {
                        wavelengthWindow = component.createObject(menuItem)
                    }
                    else
                    {
                        messageDialog.show(component.errorString())
                    }
                    wavelengthWindow.show()
                }
            }
        }

        // Changing the pathlength selected
        MenuButton {
            Layout.fillWidth: true
            id: pathlengthButton
            platformText: qsTr("  Pathlength  ")
            implicitWidth: atmModelButton.width
            setWidthFromText: false

            // Enabling opening of another window with the parameters of the pathlength for the calculation
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("Pathlength.qml")
                    if (component.status === Component.Ready)
                    {
                        pathlengthWindow = component.createObject(menuItem)
                    }
                    else
                    {
                        messageDialog.show(component.errorString())
                    }
                    pathlengthWindow.show()
                }
            }
        }

        // Changing the total pressure value
        MenuButton {
            Layout.fillWidth: true
            id: totalPressureButton
            implicitWidth: atmModelButton.width
            platformText: qsTr("  Total pressure  ")
            setWidthFromText: false

            // Enabling opening of another window with the parameters of the pathlength for the calculation
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("TotalPressure.qml")
                    if (component.status === Component.Ready)
                    {
                        totalPressureWindow = component.createObject(menuItem)
                    }
                    else
                    {
                        messageDialog.show(component.errorString())
                    }
                    totalPressureWindow.show()
                }
            }
        }

        // Changing the temperature value
        MenuButton {
            Layout.fillWidth: true
            id: temperatureButton
            implicitWidth: atmModelButton.width
            platformText: qsTr("  Temperature  ")
            setWidthFromText: false

            // Enabling opening of another window with the parameters of the pathlength for the calculation
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("Temperature.qml")
                    if (component.status === Component.Ready)
                    {
                        temperatureWindow = component.createObject(menuItem)
                    }
                    else
                    {
                        messageDialog.show(component.errorString())
                    }
                    temperatureWindow.show()
                }
            }
        }

        // Changing the vertical axis range
        MenuButton {
            Layout.fillWidth: true
            id: yAxisButton
            platformText: qsTr("Vertical axis")
            implicitWidth: atmModelButton.width
            setWidthFromText: false

            // Enabling opening of another window with the parameters of the pathlength for the calculation
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("YAxis.qml")
                    if (component.status === Component.Ready)
                    {
                        yAxisWindow = component.createObject(menuItem)
                    }
                    else
                    {
                        messageDialog.show(component.errorString())
                    }
                    yAxisWindow.show()
                }
            }
        }

        // Changing the atmospheric model selected
        MenuButton {
            Layout.fillWidth: true
            id: atmModelButton
            platformText: qsTr("  Atmosphere model  ")
            setWidthFromText: true

            // Enabling opening of another window with the parameters of the pathlength for the calculation
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("AtmosphericModel.qml")
                    if (component.status === Component.Ready)
                    {
                        atmModelWindow = component.createObject(menuItem)
                    }
                    else
                    {
                        messageDialog.show(component.errorString())
                    }
                    atmModelWindow.show()
                }
            }
        }

        // Setting the instrument function
        MenuButton {
            Layout.fillWidth: true
            id: instrFunctButton
            platformText: qsTr("Instrument funct.")
            implicitWidth: atmModelButton.width
            setWidthFromText: false

            // Enabling opening of another window with the parameters of the pathlength for the calculation
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("InstrumentFunction.qml")
                    if (component.status === Component.Ready)
                    {
                        instrFunctWindow = component.createObject(menuItem)
                    }
                    else
                    {
                        messageDialog.show(component.errorString())
                    }
                    instrFunctWindow.show()
                }
            }
        }

        // Changing line options
        MenuButton {
            Layout.fillWidth: true
            id: lineOptionsButton
            platformText: qsTr("  Line options  ")
            implicitWidth: atmModelButton.width
            setWidthFromText: false

            // Enabling opening of another window with the parameters of the pathlength for the calculation
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("LineOptions.qml")
                    if (component.status === Component.Ready)
                    {
                        lineOptionsWindow = component.createObject(menuItem)
                    }
                    else
                    {
                        messageDialog.show(component.errorString())
                    }
                    lineOptionsWindow.show()
                }
            }
        }

        // Setting the instrument function
        MenuButton {
            Layout.fillWidth: true
            id: hitranDownloadOptionsButton
            platformText: qsTr("HITRAN options")
            implicitWidth: atmModelButton.width
            setWidthFromText: false

            // Enabling opening of another window with the parameters of the pathlength for the calculation
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("HitranDownloadOptions.qml")
                    if (component.status === Component.Ready)
                    {
                        hitranDownloadOptionsWindow = component.createObject(menuItem)
                    }
                    else
                    {
                        messageDialog.show(component.errorString())
                    }
                    hitranDownloadOptionsWindow.show()
                }
            }
        }

        // Emailing the results of the calculations (the plot, data or both)
        MenuButton {
            Layout.fillWidth: true
            id: shareResultsButton
            platformText: qsTr("Share results")
            implicitWidth: atmModelButton.width
            setWidthFromText: false

            // Enabling opening of another window with the parameters of the pathlength for the calculation
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("ShareResultsChoice.qml")
                    if (component.status === Component.Ready)
                    {
                        shareResultsChoiceWindow = component.createObject(menuItem)
                    }
                    else
                    {
                        messageDialog.show(component.errorString())
                    }
                    shareResultsChoiceWindow.show()
                }
            }
        }       

        // Displaying information about the program (only displayed in the sandscape mode)
        MenuButton {
            Layout.fillWidth: true
            id: aboutButton
            platformText: qsTr("  About  ")
            implicitWidth: atmModelButton.width
            setWidthFromText: false

            // Enabling opening of another window with the parameters of the pathlength for the calculation
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("About.qml")
                    if (component.status === Component.Ready)
                    {
                        aboutWindow = component.createObject(menuItem)
                    }
                    else
                    {
                        messageDialog.show(component.errorString())
                    }
                    aboutWindow.show()
                }
            }
        }
    }
}
