// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component to specify the total pressure of the gas mixture
import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Window 2.2
import QtQuick.Dialogs 1.2
import QtQuick.Layouts 1.1

Item {

    id: totalPressureItem
    anchors.fill: parent

    // Rectangle to draw the form border
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: "black"
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        anchors.right: mainTotalPressureColumnLayout.right
        anchors.top: mainTotalPressureColumnLayout.top
        anchors.left: mainTotalPressureColumnLayout.left
        anchors.bottom: mainTotalPressureColumnLayout.bottom
        anchors.margins: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'android') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? totalPressureValueLabel.height * (-0.85) : -20
        color: "white"
        border.width: 1
        border.color: "black"
        radius: height * 0.04
    }

    // Button to close the form
    BackRectangle {
        anchors.fill: exitButton
        anchors.margins: 8
    }
    ControlButton {
        anchors.right: totalPressureItem.right
        anchors.top: totalPressureItem.top
        id: exitButton
        platformText: qsTr("X")
        opacity: 1.0

        // Enabling the closing of the form when the exit button is pressed
        MouseArea {
            anchors.fill: parent
            onClicked: {
                MolListViewModel.updatePartPress();  // Need to also update the values displayed in the molecules list (partial pressures)
                totalPressureItem.destroy();
            }
        }
    }

    // Column layout to hold all the interface items
    ColumnLayout {
        // At rotation the buttons are not positioned exactly the way they should be (fix this)
        id: mainTotalPressureColumnLayout
        anchors.centerIn: parent
        spacing: 5
        transformOrigin: Item.Center
        Layout.fillWidth: true
        Layout.fillHeight: true

        PlatformLabel {
            Layout.fillWidth: true
            id: commentLabel
            width: 120
            height: 23
            text: qsTr("Specify the total pressure units and value.")
        }

        GridLayout {

            PlatformLabel {
                id: totalPressureValueLabel
                anchors.right: totalPressureTextField.left
                Layout.column: 0
                Layout.row: 0
                width: 120
                height: 23
                text: qsTr("Total pressure:  ")
            }

            PlatformLabel {
                id: totalPressureUnitsLabel
                anchors.right: unitsComboBox.left
                Layout.column: 0
                Layout.row: 1
                width: 120
                height: 23
                text: qsTr("Units:  ")
            }

            // Changing the Pathlength value
            PlatformTextField {
                Layout.fillWidth: true
                id: totalPressureTextField
                Layout.column: 1
                Layout.row: 0
                width: 120
                height: 23
                text: totalPressObj.totalPressure
                onTextChanged: totalPressObj.totalPressure = text
            }

            // ComboBox to select the pathlength units
            PlatformComboBox {
                id: unitsComboBox
                Layout.fillWidth: true
                Layout.column: 1
                Layout.row: 1
                model: [ "Atmospheres, atm", "Millibar, mbar", "Torr, Torr", "Pascal, Pa", "Punds per square inch, psi"]
                currentIndex: totalPressObj.units
                onCurrentIndexChanged: totalPressObj.units = currentIndex
                implicitWidth: totalPressureTextField.width
                style: ((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? winReferenceComboBox.style : referenceComboBox.style
            }
            // This weird way was introduced to enable text black color under the windows phone platform while maintaining the style a default for other platforms
            PlatformComboBox {
                id: referenceComboBox
                visible: false
            }
            PlatformComboBox {
                id: winReferenceComboBox
                style: ComboBoxPlatformStyle {}
                visible: false
            }
        }
    }
}
