// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component used to change the range of calculation wavelengths
import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Window 2.2
import QtQuick.Dialogs 1.2
import QtQuick.Layouts 1.1

Item {

    id: wavelengthsItem
    anchors.fill: parent

    // Rectangle to draw the form border
    Rectangle {
        id: exitButtonRect
        anchors.fill: parent
        border.width: 1
        border.color: "black"
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    Rectangle {
        anchors.right: mainWavelengthColumnLayout.right
        anchors.top: mainWavelengthColumnLayout.top
        anchors.left: mainWavelengthColumnLayout.left
        anchors.bottom: mainWavelengthColumnLayout.bottom
        anchors.margins: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'android') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? startWavelengthLabel.height * (-0.85) : -20
        color: "white"
        border.width: 1
        border.color: "black"
        radius: height * 0.025
    }

    // Button to close the form
    BackRectangle {
        anchors.fill: exitButton
        anchors.margins: 8
    }
    ControlButton {
        anchors.right: wavelengthsItem.right
        anchors.top: wavelengthsItem.top
        id: exitButton
        platformText: qsTr("X")        

        // Enabling the closing of the form when the exit button is pressed
        MouseArea {
            anchors.fill: parent
            onClicked: {
                specResultsDataObj.updateXAxis();
                specResultsDataObj.updatePlotAllPreserveScale();
                wavelengthsItem.destroy();
            }
        }
    }

    // Grid layout with the main form components
    ColumnLayout {

        // At rotation the buttons are not positioned exactly the way they should be (fix this)
        id: mainWavelengthColumnLayout
        anchors.centerIn: parent
        spacing: 5
        transformOrigin: Item.Center
        Layout.fillWidth: true
        Layout.fillHeight: true

        PlatformLabel {
            Layout.fillWidth: true
            id: commentLabel            
            text: qsTr("Specify the units and the spectral range\nof the calculation region.")
        }

        GridLayout {

            // Changing the total pressure value
            PlatformLabel {
                id: startWavelengthLabel
                anchors.right: startWavelengthTextField.left
                Layout.column: 0
                Layout.row: 0
                text: qsTr("Start:  ")
            }

            // Emailing the results of the calculations (the plot, data or both)
            PlatformLabel {
                id: endWavelengthLabel
                anchors.right: endWavelengthTextField.left
                Layout.column: 0
                Layout.row: 1
                text: qsTr("  End:  ")
            }

            // Emailing the results of the calculations (the plot, data or both)
            PlatformLabel {
                id: resolWavelengthLabel
                anchors.right: resolutionWavelengthTextField.left
                Layout.column: 0
                Layout.row: 2
                text: qsTr("  Number  \nof points:  ")
            }

            // Emailing the results of the calculations (the plot, data or both)
            PlatformLabel {
                id: resolTitleLabel
                anchors.right: resolutionWavelengthTextField.left
                Layout.column: 0
                Layout.row: 3
                text: qsTr("Resolution:  ")
            }

            PlatformLabel {
                id: unitsLabel
                anchors.right: resolLabel.left
                Layout.column: 0
                Layout.row: 4
                text: qsTr("Units:  ")
            }

            PlatformTextField {
                Layout.fillWidth: true
                id: startWavelengthTextField
                Layout.column: 1
                Layout.row: 0
                text: wlDataObj.startWavelength
                onTextChanged: wlDataObj.startWavelength = text
            }

            // Changing the wavelength range
            PlatformTextField {
                Layout.fillWidth: true
                id: endWavelengthTextField
                Layout.column: 1
                Layout.row: 1
                text: wlDataObj.endWavelength
                onTextChanged: wlDataObj.endWavelength = text
            }

            // Changing the wavelength number of points
            PlatformTextField {
                Layout.fillWidth: true
                id: resolutionWavelengthTextField
                Layout.column: 1
                Layout.row: 2
                text: wlDataObj.numPoints
                onTextChanged: wlDataObj.numPoints = text
            }

            PlatformLabel {
                id: resolLabel
                Layout.column: 1
                Layout.row: 3
                text: wlDataObj.resolWavelength
                color: 'red'
            }

            // ComboBox to select the wavelength / wavenumber units to use in the plot display etc.
            PlatformComboBox {
                id: unitsComboBox
                Layout.fillWidth: true
                Layout.column: 1
                Layout.row: 4
                model: [ "Wavelength, nm",  "Wavelength, micron", "Wavenumber, cm-1", "Frequency, Hz" ] // 0 - Wavelength, nm;  1 - Wavelength, micron, 2 - Wavenumber, cm-1;  3 - Frequency, Hz;  ( 4 - Attenuation, Db try to add later, this is not dB but something involving Db, need to check )
                currentIndex: wlDataObj.units
                onCurrentIndexChanged: wlDataObj.units = currentIndex
                implicitWidth: resolutionWavelengthTextField.width
                //style: ((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? ComboBoxStyle : PlatformComboBox.style
                style: ((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? winReferenceComboBox.style : referenceComboBox.style
            }
            // This weird way was introduced to enable text black color under the windows phone platform while maintaining the style a default for other platforms
            PlatformComboBox {
                id: referenceComboBox
                visible: false
            }
            PlatformComboBox {
                id: winReferenceComboBox
                style: ComboBoxPlatformStyle {}
                visible: false
            }
        }
    }
}
