// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// Share results methods (for Android and iOS) are based on the tutorial and code Copyrighted (c) 2014 Nicolas Froment
// http://blog.lasconic.com/share-on-ios-and-android-using-qml/
// and the following example code has been consulted for iOS specific implementation:
// code by Richard Moe Gustavsen at https://github.com/richardmg/qtdd13_qmlapp
// code by Remko Troncon at https://github.com/remko/mixing-cocoa-and-qt/archive/master.zip
// http://www.appcoda.com/ios7-airdrop-programming-tutorial/
// http://stackoverflow.com/questions/10174063/where-does-uiimage-imagenamed-load-images-from-and-how-can-i-at-runtime-i
// http://stackoverflow.com/questions/27673722/cant-create-uiimage-with-uiimage-imagewithcontentsoffile-and-file-is-there
// http://stackoverflow.com/questions/8635909/loading-an-image-from-documents-directory
// http://stackoverflow.com/questions/1020940/loading-a-image-from-documents-directory-in-iphone
// https://codereview.qt-project.org/#/c/164723/
// https://wiki.qt.io/Building_Qt_5_from_Git#Getting_the_source_code
// And several other stackoverflow posts
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



#import "ios/iosshare.h"

#if defined(Q_OS_IOS)
    #import <UIKit/UIKit.h>
#endif

iosShare::iosShare(QObject *parent) : QObject(parent)
{

}

// These additional resources were used to suplement this method with missing functionality
// http://stackoverflow.com/questions/31955140/sharing-image-using-uiactivityviewcontroller
// http://stackoverflow.com/questions/17539932/how-to-share-multiple-images-with-uiactivityviewcontroller
// And several other stackoverflow posts
void iosShare::share(const QString &imagePath, const QString &textPath, const QString &configPath)
{
    #if defined(Q_OS_IOS)

        // Getting the main window rollview controller whatever it is
        UIViewController *qtController = [ [UIApplication sharedApplication].keyWindow rootViewController ];

        // Selective attaching of files depending on the strings passed
        if ( (imagePath.isEmpty()) && (!textPath.isEmpty()))
        {
            // Obtaining a URL for the data text file
            NSString *textFilePath = textPath.toNSString();
            NSURL *textFile = [[NSURL alloc] initFileURLWithPath:textFilePath];

            // Obtaining a URL for the configuration text file
            NSString *configFilePath = configPath.toNSString();
            NSURL *configFile = [[NSURL alloc] initFileURLWithPath:configFilePath];

            // Attach a text file only (the configuration file is included as well)
            UIActivityViewController *activityController = [[UIActivityViewController alloc] initWithActivityItems:@[textFile, configFile] applicationActivities:nil ];

            // Calling the activity controller to share the selected data files
            if ( [activityController respondsToSelector:@selector(popoverPresentationController)] )
            {
                // iOS 8
                activityController.popoverPresentationController.sourceView = qtController.view;
            }
            [ qtController presentViewController:activityController animated:YES completion:nil ];
        }
        else if ( (!imagePath.isEmpty()) && (textPath.isEmpty()))
        {
            // This results in white background but the file name is not carried over
            // NSString *pathForImage = imagePath.toNSString();
            // UIImage *image  = [[UIImage alloc] initWithContentsOfFile:pathForImage];

            // This results in transparent background but the file name is preserved
            NSString *pathForImage = imagePath.toNSString();
            NSURL *image = [[NSURL alloc] initFileURLWithPath:pathForImage];

            // Attach an image file only
            UIActivityViewController *activityController = [[UIActivityViewController alloc] initWithActivityItems:@[image] applicationActivities:nil ];

            // Calling the activity controller to share the selected data files
            if ( [activityController respondsToSelector:@selector(popoverPresentationController)] )
            {
                // iOS 8
                activityController.popoverPresentationController.sourceView = qtController.view;
            }
            [ qtController presentViewController:activityController animated:YES completion:nil ];
        }
        else if ( (!imagePath.isEmpty()) && (!textPath.isEmpty()))
        {
            // This results in white background but the file name is not carried over
            // NSString *pathForImage = imagePath.toNSString();
            // UIImage *image  = [[UIImage alloc] initWithContentsOfFile:pathForImage];

            // This results in transparent background but the file name is preserved
            NSString *pathForImage = imagePath.toNSString();
            NSURL *image = [[NSURL alloc] initFileURLWithPath:pathForImage];

            // Obtaining a URL for the data text file
            NSString *textFilePath = textPath.toNSString();
            NSURL *textFile = [[NSURL alloc] initFileURLWithPath:textFilePath];

            // Obtaining a URL for the configuration text file
            NSString *configFilePath = configPath.toNSString();
            NSURL *configFile = [[NSURL alloc] initFileURLWithPath:configFilePath];

            // Attach an image and a text file (the configuration file is included as well)
            UIActivityViewController *activityController = [[UIActivityViewController alloc] initWithActivityItems:@[image, textFile, configFile] applicationActivities:nil ];

            // Calling the activity controller to share the selected data files
            if ( [activityController respondsToSelector:@selector(popoverPresentationController)] )
            {
                // iOS 8
                activityController.popoverPresentationController.sourceView = qtController.view;
            }
            [ qtController presentViewController:activityController animated:YES completion:nil ];
        }

    #endif
}
