// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object used to login to a server (HITRAN server uses the POST method to authenticate)
#ifndef SERVERLOGIN_H
#define SERVERLOGIN_H

#include <QString>
#include <QObject>
#include <QNetworkAccessManager>

class ServerLogin : public QObject
{
    Q_OBJECT

public:

    explicit ServerLogin(QObject *parent = 0);

    // Getting and setting the host name
    QString getHostName();
    void setHostName(QString newHostName);

    // Method to get and set the email and password
    QString getEmail();
    void setEmail(QString newEmail);
    QString getPassword();
    void setPassword(QString newPassword);

    // Method to authenticate with a remote server
    void authenticate();

signals:

    // Signal is emitted on successful authentication
    void authenticationSuccessful();

public slots:

    // Slot to receive a network reply
    void onFinish(QNetworkReply *reply);

private slots:



private:

    // Method to contain connections
    void createActions();

    // Path to the remote server (host name)
    QString hostName;

    // Network manager to send and receive requests from a remote server
    QNetworkAccessManager *netManager;

    // Variables containing the email and password
    QString email;
    QString password;

};

#endif // SERVERLOGIN_H
