// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object stores the currently active temperature units and performs conversions from / to the default units to the currently active temperature units
#include "temperatureunitsconvert.h"

TemperatureUnitsConvert::TemperatureUnitsConvert()
{
}

// Method to get and set the current total pressure units
int TemperatureUnitsConvert::getUnits() { return this->currentUnits; }
void TemperatureUnitsConvert::setUnits(int newUnits) { this->currentUnits = newUnits; }

// Method to convert from default units to current units
double TemperatureUnitsConvert::fromDefaultToCurrent(double defaultValue)
{
    // Kelvin, K;  Celsius, C;  Fahrenheit, F
    switch (currentUnits)
    {
        case 0:
            return defaultValue;
            break;
        case 1:
            return defaultValue - 273.15;
            break;
        case 2:
            return defaultValue * 1.8 - 459.67;
            break;
        default:
            return defaultValue;
            break;
    }
}

// Method to convert from the current units to the default units
double TemperatureUnitsConvert::fromCurrentToDefault(double currentValue)
{
    // Kelvin, K;  Celsius, C;  Fahrenheit, F
    // Conversion of units is according to Wikipedia.org
    switch (currentUnits)
    {
        case 0:
            return currentValue;
            break;
        case 1:
            return currentValue + 273.15;
            break;
        case 2:
            return (currentValue + 459.67) * 0.55555556;
            break;
        default:
            return currentValue;
            break;
    }
}
