// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object is used to download TIPS files from the HITRAN server
#ifndef TIPSFILESDOWNLOADER_H
#define TIPSFILESDOWNLOADER_H

#include "filedownloader.h"

#include <QObject>

class TipsFilesDownloader : public QObject
{
    Q_OBJECT

public:

    explicit TipsFilesDownloader(QObject *parent = 0);

signals:

    // Method indicating that the download of the TIPS files has been successful
    void tipsFilesDownloaded(bool success);

    // Signal used to send notifications to the user of what is going on in the program
    void notify(QString message, double value, bool visible, bool cancelButtonVisible);

public slots:

public:

    // Methods to get and set the TIPS download folders
    QString getTipsDownloadPath();
    void setTipsDownloadPath(QString newTipsDownloadPath);

    // Methods to get and set the save folder on the local device where the TIPS files would be stored
    QString getTipsFolder();
    void setTipsFolder(QString newTipsFolder);

    // Getting and setting the TIPS maximum index
    int getTipsMaxIndex();
    void setTipsMaxIndex(int newTipsMaxIndex);

    // Method to initiate the download of TIPS files
    void downloadTipsFiles();

    // Method to download a single TIPS file
    void downloadOneTipsFile();

private slots:

    void tipsOneFileDownloadComplete(QByteArray *data, bool success);

private:

    // Method to create actions
    void createActions();

    // File downloader
    FileDownloader *downloader;

    // Paths to the folders to save the downloaded data to
    QString tipsFolder;      // Path to the folder with the TIPS data

    // Paths to the online download folders with the molparam and the TIPS files
    QString tipsDownloadPath;

    // Variable indicating the maximum ennumeration for a TIPS maximum index
    int tipsMaxIndex;

    int numDownloaded;  // Number of files downloaded
    int numAttempted;   // Number of attempted downloads

    QString fileName;   // Name of the IIPS file to download

};

#endif // TIPSFILESDOWNLOADER_H
