// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object is used to relay the total pressure information betweeen the C++ data objects and the QML interface
#ifndef TOTALPRESSDATAOBJECT_H
#define TOTALPRESSDATAOBJECT_H

#include <QObject>
#include "bytrancore.h"

class TotalPressDataObject : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QString totalPressure READ totalPressure WRITE setTotalPressure NOTIFY totalPressureChanged)
    Q_PROPERTY(int units READ units WRITE setUnits NOTIFY unitsChanged)

public:

    Q_INVOKABLE void updateTotalPress();  // Method to update the  total pressure displayed

    explicit TotalPressDataObject(QObject *parent = 0, BytranCore *inCore = 0);
    TotalPressDataObject(const QString &totalPressure, const int &units, QObject *parent=0);

    QString totalPressure() const;
    void setTotalPressure(const QString &totalPressure);

    int units() const;
    void setUnits(const int &units);

signals:

    void totalPressureChanged();
    void unitsChanged();

private:

    QString m_totalPressure;
    int m_units;
    BytranCore *core;

};

#endif // TOTALPRESSDATAOBJECT_H
