// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Data object linking the vertical axis window with the core module performing the calculations
#ifndef YAXISDATAOBJECT_H
#define YAXISDATAOBJECT_H

#include <QObject>
#include "bytrancore.h"


class YAxisDataObject : public QObject
{
    Q_OBJECT

    Q_PROPERTY(int units READ units WRITE setUnits NOTIFY unitsChanged)
    Q_PROPERTY(QString minimum READ minimum WRITE setMinimum NOTIFY minimumChanged)
    Q_PROPERTY(QString maximum READ maximum WRITE setMaximum NOTIFY maximumChanged)

public:

    explicit YAxisDataObject(QObject *parent = 0, BytranCore *inCore = 0);
    YAxisDataObject(const QString &minimum, const QString &maximum, const int &units, QObject *parent=0);

    // Units
    int units() const;
    void setUnits(const int &units);

    // Minimum
    QString minimum() const;
    void setMinimum(const QString &minimum);

    // Maximum
    QString maximum() const;
    void setMaximum(const QString &maximum);

signals:

    void unitsChanged();
    void minimumChanged();
    void maximumChanged();

private:

    int m_units;
    QString m_minimum;
    QString m_maximum;
    BytranCore *core;

};

#endif // YAXISDATAOBJECT_H
